@@ -1,18 +1,18 @@
 import copy
+import itertools
+import json
+import string
+from typing import Dict
+
 import pandas as pd
 import pandas_profiling
-import json
-import os
-import string
-import itertools
-
 from fuzzywuzzy import fuzz
 
 from inspec_ai.analytics import telemetry_service
 
 
 class CategoryCleaner:
-    def __init__(self, df: pd.DataFrame, pandas_profiling_report: dict=None):
+    def __init__(self, df: pd.DataFrame, pandas_profiling_report: Dict = None):
         """
 
         :param df: pd.DataFrame containing the data to be cleaned. Assumes that df has column headers
@@ -25,17 +25,15 @@ class CategoryCleaner:
         else:
             self.pandas_profiling_report = self.get_pandas_profiling_report()
 
-
     def get_pandas_profiling_report(self) -> dict:
         """
         Generates a pandas profiling report for the pd.DataFrame given as input to the class
 
-        :return: dict, containing the report's results
+        :return: Dict, containing the report's results
         """
         profile = pandas_profiling.ProfileReport(self.df, title="Pandas Profiling Report", explorative=True)
         return json.loads(profile.to_json())
 
-
     def get_string_categorical_features(self) -> list:
         """
         Finds the features that are categorical and of dtypes "object" to find string categorical features
@@ -45,14 +43,14 @@ class CategoryCleaner:
         # get categorical features
         categorical_features = []
         for feat in self.pandas_profiling_report["variables"]:
-            if self.pandas_profiling_report["variables"][feat]["type"] == 'Categorical':
+            if self.pandas_profiling_report["variables"][feat]["type"] == "Categorical":
                 categorical_features.append(feat)
 
         # get features with only strings (object) type
         types = self.df.dtypes
         object_type = list(types[types == "object"].index)
 
-        string_categorical_features=[]
+        string_categorical_features = []
         # clean each string categorical feature
         for feat in categorical_features:
             if feat in object_type:
@@ -60,8 +58,7 @@ class CategoryCleaner:
 
         return string_categorical_features
 
-
-    def get_unique_values(self, col:pd.Series) -> pd.Series:
+    def get_unique_values(self, col: pd.Series) -> pd.Series:
         """
         Finds unique values contained in "col". Ignores NaN and empty strings as unique values
 
@@ -72,8 +69,7 @@ class CategoryCleaner:
         values = values[values != ""]
         return values
 
-
-    def get_cleaned_values(self, unique_values:pd.Series) -> pd.Series:
+    def get_cleaned_values(self, unique_values: pd.Series) -> pd.Series:
         """
         Performs some cleaning operations on values in "unique_values". Assumes that "unique_values" contains strings.
 
@@ -99,8 +95,7 @@ class CategoryCleaner:
 
         return clean_values
 
-
-    def get_basic_groupings(self, col:pd.Series) -> list:
+    def get_basic_groupings(self, col: pd.Series) -> list:
         """
         Gets groupings of values contained in "col" that can be easily identified as similar.
 
@@ -123,8 +118,7 @@ class CategoryCleaner:
 
         return all_to_group
 
-
-    def get_groupings_acronym(self, col:pd.Series) -> list:
+    def get_groupings_acronym(self, col: pd.Series) -> list:
         """
         Gets groupings of values contained un "col" that are identified as being acronyms for one another. E.g. "hs" and "high school"
 
@@ -134,9 +128,8 @@ class CategoryCleaner:
         value = self.get_unique_values(col)
         value_lower = self.get_cleaned_values(value)
         df_info = pd.DataFrame({"value": value, "value_lower": value_lower})
-        df_info["value_initial"] = df_info["value"].apply(lambda x: ''.join(i[0] for i in x.split()))
-        df_info["value_initial_lower"] = df_info["value_lower"].apply(lambda x: ''.join(i[0] for i in x.split()))
-
+        df_info["value_initial"] = df_info["value"].apply(lambda x: "".join(i[0] for i in x.split()))
+        df_info["value_initial_lower"] = df_info["value_lower"].apply(lambda x: "".join(i[0] for i in x.split()))
 
         # find initials that could only come from one value
         init_lower_count = df_info["value_initial_lower"].value_counts()
@@ -152,7 +145,6 @@ class CategoryCleaner:
 
         return to_group
 
-
     def get_groupings_first_letter_of_another_value(self, col: pd.Series) -> list:
         """
         Gets groupings of values contained un "col" that are identified as being the first letter of another. E.g. "f" and "female"
@@ -169,7 +161,7 @@ class CategoryCleaner:
             if len(value) == 1:
                 just_one_letter.append(value)
 
-        starts_with = {k: [] for k in just_one_letter}
+        starts_with: Dict = {k: [] for k in just_one_letter}
 
         # find the other values that start with those single letter
         for letter in just_one_letter:
@@ -186,7 +178,6 @@ class CategoryCleaner:
 
         return to_group
 
-
     def get_levenshtein_close_values(self, col: pd.Series, threshold=85) -> list:
         """
         Gets groupings of values contained un "col" that are identified as being close to one another. E.g. "Montreal" and "Montrea"
@@ -208,13 +199,13 @@ class CategoryCleaner:
                 high_score_pairs.append(pair)
         return high_score_pairs
 
-
     # to apply only on values with more than one word
     # not optimized, but we can always repeat it
     # other way of doing levenhstein distance comparaison could be:
     # 1. you just compare with values "after" you in the list
-    # 2. once you are tagged as "similar to someone", you are not comparing yourself afterwards (you are known and have been attributed to a group, that's it, it's over for you)
-    def get_partial_levenshtein_close_values(self, col: pd.Series, threshold: int=85) -> list:
+    # 2. once you are tagged as "similar to someone", you are not comparing yourself afterwards
+    #   (you are known and have been attributed to a group, that's it, it's over for you)
+    def get_partial_levenshtein_close_values(self, col: pd.Series, threshold: int = 85) -> list:
         """
         Gets groupings of values contained un "col" that are identified as being close to one another, with partial Levenshtein metric.
         E.g. "Toronto Raptors" and "Raptors". Any string fully contained in another string will be flagged as 100 similar with partial levenshtein metric.
@@ -243,8 +234,7 @@ class CategoryCleaner:
 
         return high_score_pairs
 
-
-    def group_values_max_length(self, col: pd.Series, values_to_group: list=[] ) -> pd.Series:
+    def group_values_max_length(self, col: pd.Series, values_to_group: list = []) -> pd.Series:
         """
         Groups values passed into a single new value. E.g., if values_to_group is ["f", "female"], all "f" in "col" will be replaced by "female".
         Chooses the longest value in "values_to_group" as the value for all values mentioned in "values_to_group"
@@ -260,10 +250,9 @@ class CategoryCleaner:
             for group in values_to_group:
                 new_name = max(group, key=len).lower()
                 new_col.loc[col.isin(group)] = new_name
-                print("values " + str(group) + "have been grouped under the value \'"+ str(new_name) + "\' for column '"+ str(col.name) + "'")
+                print("values " + str(group) + "have been grouped under the value '" + str(new_name) + "' for column '" + str(col.name) + "'")
         return new_col
 
-
     def group_values_min_length(self, col: pd.Series, values_to_group: list) -> pd.Series:
         """
         Currently not used by any other method from the class.
@@ -283,9 +272,8 @@ class CategoryCleaner:
                 new_col.loc[col.isin(group)] = new_name
             return new_col
 
-
     def group_values_max_frequency(self, col: pd.Series, values_to_group: list) -> pd.Series:
-        #TODO, most likely how tableau prep chooses their new name
+        # TODO, most likely how tableau prep chooses their new name
         """
         Currently not used by any other method from the class.
         Groups values passed into a single new value. E.g., if "col" is ["f", "female", "female", "male"].
@@ -294,8 +282,7 @@ class CategoryCleaner:
         """
         return None
 
-
-    def get_cleaned_column(self, col:pd.Series) -> pd.Series:
+    def get_cleaned_column(self, col: pd.Series) -> pd.Series:
         """
         Groups all values that are similar in "col" into a single value. Applies many different rules to identify similar values.
 
